@@ -27,6 +27,7 @@
 #include <gnutls_global.h>
 #include <gnutls_dh.h>
 #include <gnutls_pk.h>
+#include <x509/common.h>
 #include <gnutls/crypto.h>
 #include "x509/x509_int.h"
 #include "debug.h"
@@ -340,9 +341,57 @@ gnutls_dh_params_export_pkcs3 (gnutls_dh_params_t params,
                                gnutls_x509_crt_fmt_t format,
                                unsigned char *params_data,
                                size_t * params_data_size)
+{
+gnutls_datum_t out;
+int ret;
+
+  ret = gnutls_dh_params_export2_pkcs3( params, format, &out);
+  if (ret < 0)
+    return gnutls_assert_val(ret);
+  
+  if (*params_data_size < (unsigned) out.size+1)
+    {
+      gnutls_assert ();
+      gnutls_free (out.data);
+      *params_data_size = out.size + 1;
+      return GNUTLS_E_SHORT_MEMORY_BUFFER;
+    }
+  
+  *params_data_size = out.size;
+  if (params_data)
+    {
+      memcpy( params_data, out.data, out.size);
+      params_data[out.size] = 0;
+    }
+  
+  gnutls_free(out.data);
+  
+  return 0;
+}
+
+/**
+ * gnutls_dh_params_export2_pkcs3:
+ * @params: Holds the DH parameters
+ * @format: the format of output params. One of PEM or DER.
+ * @out: will contain a PKCS3 DHParams structure PEM or DER encoded
+ *
+ * This function will export the given dh parameters to a PKCS3
+ * DHParams structure. This is the format generated by "openssl dhparam" tool.
+ * The data in @out will be allocated using gnutls_malloc().
+ *
+ * If the structure is PEM encoded, it will have a header
+ * of "BEGIN DH PARAMETERS".
+ *
+ * Returns: On success, %GNUTLS_E_SUCCESS (0) is returned,
+ *   otherwise a negative error code is returned.
+ **/
+int
+gnutls_dh_params_export2_pkcs3 (gnutls_dh_params_t params,
+                                gnutls_x509_crt_fmt_t format,
+                                gnutls_datum_t * out)
 {
   ASN1_TYPE c2;
-  int result, _params_data_size;
+  int result;
   size_t g_size, p_size;
   uint8_t *p_data, *g_data;
   uint8_t *all_data;
@@ -395,6 +444,7 @@ gnutls_dh_params_export_pkcs3 (gnutls_dh_params_t params,
   if (result < 0)
     {
       gnutls_assert ();
+      gnutls_free (all_data);
       asn1_delete_structure (&c2);
       return _gnutls_asn2err (result);
     }
@@ -415,78 +465,34 @@ gnutls_dh_params_export_pkcs3 (gnutls_dh_params_t params,
 
   if (format == GNUTLS_X509_FMT_DER)
     {
-      if (params_data == NULL)
-        *params_data_size = 0;
+      result = _gnutls_x509_der_encode(c2, "", out, 0);
 
-      _params_data_size = *params_data_size;
-      result =
-        asn1_der_coding (c2, "", params_data, &_params_data_size, NULL);
-      *params_data_size = _params_data_size;
       asn1_delete_structure (&c2);
 
-      if (result != ASN1_SUCCESS)
-        {
-          gnutls_assert ();
-          if (result == ASN1_MEM_ERROR)
-            return GNUTLS_E_SHORT_MEMORY_BUFFER;
-
-          return _gnutls_asn2err (result);
-        }
+      if (result < 0)
+        return gnutls_assert_val (result);
 
     }
   else
     {                           /* PEM */
-      uint8_t *tmp;
-      gnutls_datum_t out;
-      int len;
+      gnutls_datum_t t;
 
-      len = 0;
-      asn1_der_coding (c2, "", NULL, &len, NULL);
-
-      tmp = gnutls_malloc (len);
-      if (tmp == NULL)
-        {
-          gnutls_assert ();
-          asn1_delete_structure (&c2);
-          return GNUTLS_E_MEMORY_ERROR;
-        }
-
-      if ((result =
-           asn1_der_coding (c2, "", tmp, &len, NULL)) != ASN1_SUCCESS)
-        {
-          gnutls_assert ();
-          gnutls_free (tmp);
-          asn1_delete_structure (&c2);
-          return _gnutls_asn2err (result);
-        }
+      result = _gnutls_x509_der_encode(c2, "", &t, 0);
 
       asn1_delete_structure (&c2);
 
-      result = _gnutls_fbase64_encode ("DH PARAMETERS", tmp, len, &out);
+      if (result < 0)
+        return gnutls_assert_val (result);
 
-      gnutls_free (tmp);
+      result = _gnutls_fbase64_encode("DH PARAMETERS", t.data, t.size, out);
+
+      gnutls_free (t.data);
 
       if (result < 0)
         {
           gnutls_assert ();
           return result;
         }
-
-      if ((unsigned) out.size > *params_data_size)
-        {
-          gnutls_assert ();
-          gnutls_free (out.data);
-          *params_data_size = out.size + 1;
-          return GNUTLS_E_SHORT_MEMORY_BUFFER;
-        }
-
-      *params_data_size = out.size;
-
-      if (params_data)
-        memcpy (params_data, out.data, out.size);
-
-      gnutls_free (out.data);
-
     }
 
   return 0;
