@@ -38,6 +38,7 @@
 #include <debug.h>
 #include <x509_b64.h>
 #include <gnutls_x509.h>
+#include <gnutls/ocsp.h>
 #include "x509/common.h"
 #include "x509/x509_int.h"
 #include <gnutls_str_array.h>
@@ -54,9 +55,9 @@
  * is unacceptable.
   */
 inline static int
-check_bits (gnutls_x509_crt_t crt, unsigned int max_bits)
+check_bits (gnutls_session_t session, gnutls_x509_crt_t crt, unsigned int max_bits)
 {
-  int ret;
+  int ret, pk;
   unsigned int bits;
 
   ret = gnutls_x509_crt_get_pk_algorithm (crt, &bits);
@@ -65,6 +66,7 @@ check_bits (gnutls_x509_crt_t crt, unsigned int max_bits)
       gnutls_assert ();
       return ret;
     }
+  pk = ret;
 
   if (bits > max_bits && max_bits > 0)
     {
@@ -72,9 +74,130 @@ check_bits (gnutls_x509_crt_t crt, unsigned int max_bits)
       return GNUTLS_E_CONSTRAINT_ERROR;
     }
 
+  if (gnutls_pk_bits_to_sec_param(pk, bits) == GNUTLS_SEC_PARAM_INSECURE)
+    {
+      gnutls_assert();
+      _gnutls_audit_log(session, "The security level of the certificate (%s: %u) is weak\n", gnutls_pk_get_name(pk), bits);
+      if (session->internals.priorities.allow_weak_keys == 0)
+        return gnutls_assert_val(GNUTLS_E_CERTIFICATE_ERROR);
+    }
+
   return 0;
 }
 
+/* three days */
+#define MAX_OCSP_VALIDITY_SECS (3*60*60*24)
+
+/* If the certificate is revoked status will be GNUTLS_CERT_REVOKED.
+ * 
+ * Returns:
+ *  Zero on success, a negative error code otherwise.
+ */
+static int
+check_ocsp_response (gnutls_session_t session, gnutls_x509_crt_t cert,
+                     gnutls_x509_crt_t issuer,
+                     gnutls_datum_t *data, unsigned int * ostatus)
+{
+  gnutls_ocsp_resp_t resp;
+  int ret;
+  unsigned int status, cert_status;
+  time_t rtime, vtime, ntime, now;
+  int check_failed = 0;
+  
+  now = gnutls_time(0);
+
+  ret = gnutls_ocsp_resp_init (&resp);
+  if (ret < 0)
+    return gnutls_assert_val(ret);
+
+  ret = gnutls_ocsp_resp_import (resp, data);
+  if (ret < 0)
+    {
+      _gnutls_audit_log (session, "There was an error parsing the OCSP response: %s.\n", gnutls_strerror(ret));
+      ret = gnutls_assert_val(0);
+      check_failed = 1;
+      goto cleanup;
+    }
+  
+  ret = gnutls_ocsp_resp_check_crt(resp, 0, cert);
+  if (ret < 0)
+    {
+      ret = gnutls_assert_val(0);
+      _gnutls_audit_log (session, "Got OCSP response with an unrelated certificate.\n");
+      check_failed = 1;
+      goto cleanup;
+    }
+
+  ret = gnutls_ocsp_resp_verify_direct( resp, issuer, &status, 0);
+  if (ret < 0)
+    {
+      ret = gnutls_assert_val(0);
+      gnutls_assert();
+      check_failed = 1;
+      goto cleanup;
+    }
+
+  /* do not consider revocation data if response was not verified */
+  if (status != 0)
+    {
+      ret = gnutls_assert_val(0);
+      check_failed = 1;
+      goto cleanup;
+    }
+
+  ret = gnutls_ocsp_resp_get_single(resp, 0, NULL, NULL, NULL, NULL,
+        &cert_status, &vtime, &ntime, &rtime, NULL);
+  if (ret < 0)
+    {
+      _gnutls_audit_log (session, "There was an error parsing the OCSP response: %s.\n", gnutls_strerror(ret));
+      ret = gnutls_assert_val(0);
+      check_failed = 1;
+      goto cleanup;
+    }
+  
+  if (cert_status == GNUTLS_OCSP_CERT_REVOKED)
+    {
+      _gnutls_audit_log(session, "The certificate was revoked via OCSP\n");
+      check_failed = 1;
+      *ostatus |= GNUTLS_CERT_REVOKED;
+      ret = gnutls_assert_val(0);
+      goto cleanup;
+    }
+  
+  /* Report but do not fail on the following errors. That is
+   * because including the OCSP response in the handshake shouldn't 
+   * cause more problems that not including it.
+   */
+  if (ntime == -1)
+    {
+      if (now - vtime > MAX_OCSP_VALIDITY_SECS)
+        {
+          _gnutls_audit_log(session, "The OCSP response is old\n");
+          check_failed = 1;
+          goto cleanup;
+        }
+    }
+  else
+    {
+      /* there is a newer OCSP answer, don't trust this one */
+      if (ntime < now)
+        {
+          _gnutls_audit_log(session, "There is a newer OCSP response but was not provided by the server\n");
+          check_failed = 1;
+          goto cleanup;
+        }
+    }
+
+  ret = 0;
+cleanup:
+  if (check_failed == 0)
+    session->internals.ocsp_check_ok = 1;
+
+  gnutls_ocsp_resp_deinit (resp);
+  
+  return ret;
+}
+
 
 #define CLEAR_CERTS for(x=0;x<peer_certificate_list_size;x++) { \
 	if (peer_certificate_list[x]) \
@@ -93,12 +216,20 @@ check_bits (gnutls_x509_crt_t crt, unsigned int max_bits)
  -*/
 int
 _gnutls_x509_cert_verify_peers (gnutls_session_t session,
+                                const char* hostname,
                                 unsigned int *status)
 {
   cert_auth_info_t info;
   gnutls_certificate_credentials_t cred;
   gnutls_x509_crt_t *peer_certificate_list;
+  gnutls_datum_t resp;
   int peer_certificate_list_size, i, x, ret;
+  gnutls_x509_crt_t issuer;
+  unsigned int ocsp_status = 0;
+  unsigned int verify_flags;
+
+  /* No OCSP check so far */
+  session->internals.ocsp_check_ok = 0;
 
   CHECK_AUTH (GNUTLS_CRD_CERTIFICATE, GNUTLS_E_INVALID_REQUEST);
 
@@ -110,7 +241,7 @@ _gnutls_x509_cert_verify_peers (gnutls_session_t session,
     }
 
   cred = (gnutls_certificate_credentials_t)
-    _gnutls_get_cred (session->key, GNUTLS_CRD_CERTIFICATE, NULL);
+    _gnutls_get_cred (session, GNUTLS_CRD_CERTIFICATE, NULL);
   if (cred == NULL)
     {
       gnutls_assert ();
@@ -126,6 +257,7 @@ _gnutls_x509_cert_verify_peers (gnutls_session_t session,
       return GNUTLS_E_CONSTRAINT_ERROR;
     }
 
+  verify_flags = cred->verify_flags | session->internals.priorities.additional_verify_flags;
   /* generate a list of gnutls_certs based on the auth info
    * raw certs.
    */
@@ -159,7 +291,7 @@ _gnutls_x509_cert_verify_peers (gnutls_session_t session,
           return ret;
         }
 
-      ret = check_bits (peer_certificate_list[i], cred->verify_bits);
+      ret = check_bits (session, peer_certificate_list[i], cred->verify_bits);
       if (ret < 0)
         {
           gnutls_assert ();
@@ -169,45 +301,58 @@ _gnutls_x509_cert_verify_peers (gnutls_session_t session,
 
     }
 
+  /* Use the OCSP extension if any */
+  if (verify_flags & GNUTLS_VERIFY_DISABLE_CRL_CHECKS)
+    goto skip_ocsp;
+  
+  ret = gnutls_ocsp_status_request_get(session, &resp);
+  if (ret < 0)
+    goto skip_ocsp;
+
+  if (peer_certificate_list_size > 1)
+    issuer = peer_certificate_list[1];
+  else
+    {
+      ret = gnutls_x509_trust_list_get_issuer(cred->tlist, peer_certificate_list[0],
+                                              &issuer, 0);
+      if (ret < 0)
+        {
+          goto skip_ocsp;
+        }
+    }
+
+  ret = check_ocsp_response(session, peer_certificate_list[0], issuer, &resp, &ocsp_status);
+  if (ret < 0)
+    {
+      CLEAR_CERTS;
+      return gnutls_assert_val(ret);
+    }
+
+skip_ocsp:
   /* Verify certificate 
    */
-
   ret = gnutls_x509_trust_list_verify_crt (cred->tlist, peer_certificate_list,
                                      peer_certificate_list_size,
-                                     cred->verify_flags | session->internals.
-                                     priorities.additional_verify_flags,
-                                     status, NULL);
-
-  CLEAR_CERTS;
+                                     verify_flags, status, NULL);
 
   if (ret < 0)
     {
       gnutls_assert ();
+      CLEAR_CERTS;
       return ret;
     }
 
-  return 0;
-}
-
-/*
- * Read certificates and private keys, from files, memory etc.
- */
-
-/* returns error if the certificate has different algorithm than
- * the given key parameters.
- */
-static int
-_gnutls_check_key_cert_match (gnutls_certificate_credentials_t res)
-{
-  int pk = gnutls_pubkey_get_pk_algorithm(res->certs[res->ncerts-1].cert_list[0].pubkey, NULL);
-
-  if (gnutls_privkey_get_pk_algorithm (res->pkey[res->ncerts - 1], NULL) !=
-      pk)
+  if (hostname)
     {
-      gnutls_assert ();
-      return GNUTLS_E_CERTIFICATE_KEY_MISMATCH;
+      ret = gnutls_x509_crt_check_hostname( peer_certificate_list[0], hostname);
+      if (ret == 0)
+        *status |= GNUTLS_CERT_UNEXPECTED_OWNER;
     }
 
+  CLEAR_CERTS;
+
+  *status |= ocsp_status;
+
   return 0;
 }
 
@@ -629,10 +774,9 @@ read_cas_url (gnutls_certificate_credentials_t res, const char *url)
   ret =
     gnutls_x509_crt_list_import_pkcs11 (xcrt_list, pcrt_list_size, pcrt_list,
                                         0);
-  if (xcrt_list == NULL)
+  if (ret < 0)
     {
       gnutls_assert ();
-      ret = GNUTLS_E_MEMORY_ERROR;
       goto cleanup;
     }
 
@@ -1185,7 +1329,7 @@ add_new_crt_to_rdn_seq (gnutls_certificate_credentials_t res, gnutls_x509_crt_t*
   gnutls_datum_t tmp;
   int ret;
   size_t newsize;
-  unsigned char *newdata;
+  unsigned char *newdata, *p;
   unsigned i;
 
   /* Add DN of the last added CAs to the RDN sequence
@@ -1225,7 +1369,11 @@ add_new_crt_to_rdn_seq (gnutls_certificate_credentials_t res, gnutls_x509_crt_t*
           return GNUTLS_E_MEMORY_ERROR;
         }
 
-      _gnutls_write_datum16 (newdata + res->x509_rdn_sequence.size, tmp);
+      p = newdata + res->x509_rdn_sequence.size;
+      _gnutls_write_uint16 (tmp.size, p);
+      if (tmp.data != NULL)
+        memcpy (p+2, tmp.data, tmp.size);
+
       _gnutls_free_datum (&tmp);
 
       res->x509_rdn_sequence.size = newsize;
