@@ -103,9 +103,6 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "AccessDescription", 1610612741, NULL },
   { "accessMethod", 1073741836, NULL },
   { "accessLocation", 2, "GeneralName"},
-  { "CRLNumber", 1611137027, NULL },
-  { "0", 10, "MAX"},
-  { "CertificateIssuer", 1073741826, "GeneralNames"},
   { "NumericString", 1610620935, NULL },
   { NULL, 4360, "18"},
   { "IA5String", 1610620935, NULL },
@@ -134,8 +131,6 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "joint-iso-ccitt", 1073741825, "2"},
   { "ds", 1073741825, "5"},
   { NULL, 1, "4"},
-  { "PostalAddress", 1610612747, NULL },
-  { NULL, 2, "DirectoryString"},
   { "emailAddress", 1880096780, "AttributeType"},
   { "iso", 1073741825, "1"},
   { "member-body", 1073741825, "2"},
@@ -144,8 +139,6 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "pkcs", 1073741825, "1"},
   { NULL, 1073741825, "9"},
   { NULL, 1, "1"},
-  { "Pkcs9email", 1612709890, "IA5String"},
-  { "ub-emailaddress-length", 524298, "1"},
   { "Name", 1610612754, NULL },
   { "rdnSequence", 2, "RDNSequence"},
   { "RDNSequence", 1610612747, NULL },
@@ -159,8 +152,8 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "signatureAlgorithm", 1073741826, "AlgorithmIdentifier"},
   { "signature", 6, NULL },
   { "TBSCertificate", 1610612741, NULL },
-  { "version", 1610653698, "Version"},
-  { NULL, 1073741833, "v1"},
+  { "version", 1610653699, NULL },
+  { NULL, 1073741833, "0"},
   { NULL, 2056, "0"},
   { "serialNumber", 1073741826, "CertificateSerialNumber"},
   { "signature", 1073741826, "AlgorithmIdentifier"},
@@ -174,10 +167,6 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { NULL, 4104, "2"},
   { "extensions", 536895490, "Extensions"},
   { NULL, 2056, "3"},
-  { "Version", 1610874883, NULL },
-  { "v1", 1073741825, "0"},
-  { "v2", 1073741825, "1"},
-  { "v3", 1, "2"},
   { "CertificateSerialNumber", 1073741827, NULL },
   { "Validity", 1610612741, NULL },
   { "notBefore", 1073741826, "Time"},
@@ -202,7 +191,7 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "signatureAlgorithm", 1073741826, "AlgorithmIdentifier"},
   { "signature", 6, NULL },
   { "TBSCertList", 1610612741, NULL },
-  { "version", 1073758210, "Version"},
+  { "version", 1073758211, NULL },
   { "signature", 1073741826, "AlgorithmIdentifier"},
   { "issuer", 1073741826, "Name"},
   { "thisUpdate", 1073741826, "Time"},
@@ -256,12 +245,11 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { NULL, 1073743880, "0"},
   { "contentType", 1, NULL },
   { "pkcs-7-DigestInfo", 1610612741, NULL },
-  { "digestAlgorithm", 1073741826, "pkcs-7-DigestAlgorithmIdentifier"},
-  { "digest", 2, "pkcs-7-Digest"},
-  { "pkcs-7-Digest", 1073741831, NULL },
+  { "digestAlgorithm", 1073741826, "AlgorithmIdentifier"},
+  { "digest", 7, NULL },
   { "pkcs-7-ContentType", 1073741836, NULL },
   { "pkcs-7-SignedData", 1610612741, NULL },
-  { "version", 1073741826, "pkcs-7-CMSVersion"},
+  { "version", 1073741827, NULL },
   { "digestAlgorithms", 1073741826, "pkcs-7-DigestAlgorithmIdentifiers"},
   { "encapContentInfo", 1073741826, "pkcs-7-EncapsulatedContentInfo"},
   { "certificates", 1610637314, "pkcs-7-CertificateSet"},
@@ -269,15 +257,8 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "crls", 1610637314, "pkcs-7-CertificateRevocationLists"},
   { NULL, 4104, "1"},
   { "signerInfos", 2, "pkcs-7-SignerInfos"},
-  { "pkcs-7-CMSVersion", 1610874883, NULL },
-  { "v0", 1073741825, "0"},
-  { "v1", 1073741825, "1"},
-  { "v2", 1073741825, "2"},
-  { "v3", 1073741825, "3"},
-  { "v4", 1, "4"},
   { "pkcs-7-DigestAlgorithmIdentifiers", 1610612751, NULL },
-  { NULL, 2, "pkcs-7-DigestAlgorithmIdentifier"},
-  { "pkcs-7-DigestAlgorithmIdentifier", 1073741826, "AlgorithmIdentifier"},
+  { NULL, 2, "AlgorithmIdentifier"},
   { "pkcs-7-EncapsulatedContentInfo", 1610612741, NULL },
   { "eContentType", 1073741826, "pkcs-7-ContentType"},
   { "eContent", 536895495, NULL },
@@ -291,8 +272,7 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "pkcs-7-SignerInfos", 1610612751, NULL },
   { NULL, 13, NULL },
   { "pkcs-10-CertificationRequestInfo", 1610612741, NULL },
-  { "version", 1610874883, NULL },
-  { "v1", 1, "0"},
+  { "version", 1073741827, NULL },
   { "subject", 1073741826, "Name"},
   { "subjectPKInfo", 1073741826, "SubjectPublicKeyInfo"},
   { "attributes", 536879106, "Attributes"},
@@ -316,14 +296,11 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "utf8String", 2, "UTF8String"},
   { "pkcs-9-localKeyId", 1073741831, NULL },
   { "pkcs-8-PrivateKeyInfo", 1610612741, NULL },
-  { "version", 1073741826, "pkcs-8-Version"},
+  { "version", 1073741827, NULL },
   { "privateKeyAlgorithm", 1073741826, "AlgorithmIdentifier"},
-  { "privateKey", 1073741826, "pkcs-8-PrivateKey"},
+  { "privateKey", 1073741831, NULL },
   { "attributes", 536895490, "Attributes"},
   { NULL, 4104, "0"},
-  { "pkcs-8-Version", 1610874883, NULL },
-  { "v1", 1, "0"},
-  { "pkcs-8-PrivateKey", 1073741831, NULL },
   { "pkcs-8-Attributes", 1610612751, NULL },
   { NULL, 2, "Attribute"},
   { "pkcs-8-EncryptedPrivateKeyInfo", 1610612741, NULL },
@@ -373,9 +350,7 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { NULL, 1073743880, "0"},
   { "badId", 1, NULL },
   { "bagAttributes", 536887311, NULL },
-  { NULL, 2, "pkcs-12-PKCS12Attribute"},
-  { "pkcs-12-KeyBag", 1073741826, "pkcs-8-PrivateKeyInfo"},
-  { "pkcs-12-PKCS8ShroudedKeyBag", 1073741826, "pkcs-8-EncryptedPrivateKeyInfo"},
+  { NULL, 2, "Attribute"},
   { "pkcs-12-CertBag", 1610612741, NULL },
   { "certId", 1073741836, NULL },
   { "certValue", 541073421, NULL },
@@ -391,20 +366,18 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "secretValue", 541073421, NULL },
   { NULL, 1073743880, "0"},
   { "secretTypeId", 1, NULL },
-  { "pkcs-12-PKCS12Attribute", 1073741826, "Attribute"},
   { "pkcs-7-Data", 1073741831, NULL },
   { "pkcs-7-EncryptedData", 1610612741, NULL },
-  { "version", 1073741826, "pkcs-7-CMSVersion"},
+  { "version", 1073741827, NULL },
   { "encryptedContentInfo", 1073741826, "pkcs-7-EncryptedContentInfo"},
   { "unprotectedAttrs", 536895490, "pkcs-7-UnprotectedAttributes"},
   { NULL, 4104, "1"},
   { "pkcs-7-EncryptedContentInfo", 1610612741, NULL },
   { "contentType", 1073741826, "pkcs-7-ContentType"},
   { "contentEncryptionAlgorithm", 1073741826, "pkcs-7-ContentEncryptionAlgorithmIdentifier"},
-  { "encryptedContent", 536895490, "pkcs-7-EncryptedContent"},
+  { "encryptedContent", 536895495, NULL },
   { NULL, 4104, "0"},
   { "pkcs-7-ContentEncryptionAlgorithmIdentifier", 1073741826, "AlgorithmIdentifier"},
-  { "pkcs-7-EncryptedContent", 1073741831, NULL },
   { "pkcs-7-UnprotectedAttributes", 1612709903, NULL },
   { "MAX", 1074266122, "1"},
   { NULL, 2, "Attribute"},
@@ -420,8 +393,8 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "optionalSignature", 536895490, "Signature"},
   { NULL, 2056, "0"},
   { "TBSRequest", 1610612741, NULL },
-  { "version", 1610653698, "Version"},
-  { NULL, 1073741833, "v1"},
+  { "version", 1610653699, NULL },
+  { NULL, 1073741833, "0"},
   { NULL, 2056, "0"},
   { "requestorName", 1610637314, "GeneralName"},
   { NULL, 2056, "1"},
@@ -466,8 +439,8 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { NULL, 1073743880, "0"},
   { NULL, 2, "Certificate"},
   { "ResponseData", 1610612741, NULL },
-  { "version", 1610653698, "Version"},
-  { NULL, 1073741833, "v1"},
+  { "version", 1610653699, NULL },
+  { NULL, 1073741833, "0"},
   { NULL, 2056, "0"},
   { "responderID", 1073741826, "ResponderID"},
   { "producedAt", 1082130449, NULL },
@@ -478,9 +451,8 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "ResponderID", 1610612754, NULL },
   { "byName", 1610620930, "RDNSequence"},
   { NULL, 2056, "1"},
-  { "byKey", 536879106, "KeyHash"},
+  { "byKey", 536879111, NULL },
   { NULL, 4104, "2"},
-  { "KeyHash", 1073741831, NULL },
   { "SingleResponse", 1610612741, NULL },
   { "certID", 1073741826, "CertID"},
   { "certStatus", 1073741826, "CertStatus"},
@@ -501,12 +473,6 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "revocationReason", 536895490, "CRLReason"},
   { NULL, 2056, "0"},
   { "UnknownInfo", 1073741844, NULL },
-  { "ArchiveCutoff", 1082130449, NULL },
-  { "AcceptableResponses", 1610612747, NULL },
-  { NULL, 12, NULL },
-  { "ServiceLocator", 1610612741, NULL },
-  { "issuer", 1073741826, "Name"},
-  { "locator", 2, "AuthorityInfoAccessSyntax"},
   { "CRLReason", 537133077, NULL },
   { "unspecified", 1073741825, "0"},
   { "keyCompromise", 1073741825, "1"},
