@@ -28,14 +28,14 @@
 #include <gnutls_sig.h>
 #include <gnutls_str.h>
 #include <gnutls_datum.h>
-#include <hash.h>
+#include <hash-pjw-bare.h>
 #include "x509_int.h"
 #include <common.h>
 #include "verify-high.h"
 
 struct named_cert_st {
   gnutls_x509_crt_t cert;
-  uint8_t name[MAX_NAME_SIZE];
+  uint8_t name[MAX_SERVER_NAME_SIZE];
   unsigned int name_size;
 };
 
@@ -57,7 +57,6 @@ struct gnutls_x509_trust_list_st {
   struct node_st *node;
 };
 
-#define INIT_HASH 0x33a1
 #define DEFAULT_SIZE 503
 
 /**
@@ -128,6 +127,11 @@ gnutls_x509_trust_list_deinit(gnutls_x509_trust_list_t list,
                 gnutls_x509_crl_deinit(list->node[i].crls[j]);
             }
         gnutls_free(list->node[i].crls);
+
+        if (all)
+            for (j = 0; j < list->node[i].named_cert_size; j++) {
+                gnutls_x509_crt_deinit(list->node[i].named_certs[j].cert);
+            }
         gnutls_free(list->node[i].named_certs);
     }
 
@@ -166,7 +170,7 @@ gnutls_x509_trust_list_add_cas(gnutls_x509_trust_list_t list,
             return i;
         }
 
-        hash = _gnutls_bhash(dn.data, dn.size, INIT_HASH);
+        hash = hash_pjw_bare(dn.data, dn.size);
         hash %= list->size;
 
         _gnutls_free_datum(&dn);
@@ -223,7 +227,7 @@ gnutls_x509_trust_list_add_named_crt(gnutls_x509_trust_list_t list,
     int ret;
     uint32_t hash;
 
-    if (name_size >= MAX_NAME_SIZE)
+    if (name_size >= MAX_SERVER_NAME_SIZE)
         return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
 
     ret = gnutls_x509_crt_get_raw_issuer_dn(cert, &dn);
@@ -232,7 +236,7 @@ gnutls_x509_trust_list_add_named_crt(gnutls_x509_trust_list_t list,
         return ret;
     }
 
-    hash = _gnutls_bhash(dn.data, dn.size, INIT_HASH);
+    hash = hash_pjw_bare(dn.data, dn.size);
     hash %= list->size;
 
     _gnutls_free_datum(&dn);
@@ -300,7 +304,7 @@ gnutls_x509_trust_list_add_crls(gnutls_x509_trust_list_t list,
             return i;
         }
 
-        hash = _gnutls_bhash(dn.data, dn.size, INIT_HASH);
+        hash = hash_pjw_bare(dn.data, dn.size);
         hash %= list->size;
 
         _gnutls_free_datum(&dn);
@@ -350,18 +354,6 @@ static int shorten_clist(gnutls_x509_trust_list_t list,
     uint32_t hash;
     gnutls_datum_t dn;
 
-    /* Start by truncating any disjoint list of certificates. For
-     * example, if the server presented a chain A->B->C->X->Y->Z
-     * where X is *not* actually the issuer of C, truncate at C.
-     */
-    for(i=1;i<clist_size;i++) {
-        if (!gnutls_x509_crt_check_issuer(certificate_list[i-1],
-                                          certificate_list[i])) {
-            gnutls_assert();
-            clist_size = i;
-        }
-    }
-
     if (clist_size > 1) {
         /* Check if the last certificate in the path is self signed.
          * In that case ignore it (a certificate is trusted only if it
@@ -391,7 +383,7 @@ static int shorten_clist(gnutls_x509_trust_list_t list,
             return ret;
         }
 
-        hash = _gnutls_bhash(dn.data, dn.size, INIT_HASH);
+        hash = hash_pjw_bare(dn.data, dn.size);
         hash %= list->size;
 
         _gnutls_free_datum(&dn);
@@ -411,6 +403,70 @@ static int shorten_clist(gnutls_x509_trust_list_t list,
     return clist_size;
 }
 
+/* Takes a certificate list and orders it with subject, issuer order.
+ *
+ * *clist_size contains the size of the ordered list (which is always less or
+ * equal to the original).
+ *
+ * Returns the sorted list which may be the original clist.
+ */
+static gnutls_x509_crt_t* sort_clist(gnutls_x509_crt_t sorted[DEFAULT_MAX_VERIFY_DEPTH], 
+                                     gnutls_x509_crt_t * clist,
+                                     unsigned int *clist_size)
+{
+  int prev;
+  unsigned int j, i;
+  int issuer[DEFAULT_MAX_VERIFY_DEPTH]; /* contain the index of the issuers */
+    
+    /* Do not bother sorting if too many certificates are given.
+     * Prevent any DoS attacks.
+     */
+  if (*clist_size > DEFAULT_MAX_VERIFY_DEPTH)
+    return clist;
+
+  for (i=0;i<DEFAULT_MAX_VERIFY_DEPTH;i++)
+    issuer[i] = -1;
+
+  /* Find the issuer of each certificate and store it
+   * in issuer array.
+   */
+  for(i=0;i<*clist_size;i++) 
+    {
+      for (j=1;j<*clist_size;j++) 
+        {
+          if (i==j) continue;
+        
+          if (gnutls_x509_crt_check_issuer(clist[i],
+                                           clist[j])) 
+            {
+              issuer[i] = j;
+              break;
+            }
+        }
+    }
+  
+  if (issuer[0] == -1)
+    {
+      *clist_size = 1;
+      return clist;
+    }
+  
+  prev = 0;
+  sorted[0] = clist[0];
+  for (i=1;i<*clist_size;i++)
+    {
+      prev = issuer[prev];
+      if (prev == -1) /* no issuer */
+        {
+          *clist_size = i;
+          break;
+        }
+      sorted[i] = clist[prev];
+    }
+  
+  return sorted;
+}
+
 /**
  * gnutls_x509_trust_list_get_issuer:
  * @list: The structure of the list
@@ -442,7 +498,7 @@ int gnutls_x509_trust_list_get_issuer(gnutls_x509_trust_list_t list,
         return ret;
     }
 
-    hash = _gnutls_bhash(dn.data, dn.size, INIT_HASH);
+    hash = hash_pjw_bare(dn.data, dn.size);
     hash %= list->size;
 
     _gnutls_free_datum(&dn);
@@ -470,7 +526,8 @@ int gnutls_x509_trust_list_get_issuer(gnutls_x509_trust_list_t list,
  * @func: If non-null will be called on each chain element verification with the output.
  *
  * This function will try to verify the given certificate and return
- * its status.
+ * its status. The @verify parameter will hold an OR'ed sequence of
+ * %gnutls_certificate_status_t flags.
  *
  * Limitation: Pathlen constraints or key usage flags are not consulted.
  *
@@ -491,10 +548,14 @@ gnutls_x509_trust_list_verify_crt(gnutls_x509_trust_list_t list,
     int ret;
     unsigned int i;
     uint32_t hash;
+    gnutls_x509_crt_t sorted[DEFAULT_MAX_VERIFY_DEPTH];
 
     if (cert_list == NULL || cert_list_size < 1)
         return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
 
+    if (!(flags & GNUTLS_VERIFY_DO_NOT_ALLOW_UNSORTED_CHAIN))
+      cert_list = sort_clist(sorted, cert_list, &cert_list_size);
+
     cert_list_size = shorten_clist(list, cert_list, cert_list_size);
     if (cert_list_size <= 0)
         return gnutls_assert_val(GNUTLS_E_INTERNAL_ERROR);
@@ -507,7 +568,7 @@ gnutls_x509_trust_list_verify_crt(gnutls_x509_trust_list_t list,
         return ret;
     }
 
-    hash = _gnutls_bhash(dn.data, dn.size, INIT_HASH);
+    hash = hash_pjw_bare(dn.data, dn.size);
     hash %= list->size;
 
     _gnutls_free_datum(&dn);
@@ -541,7 +602,7 @@ gnutls_x509_trust_list_verify_crt(gnutls_x509_trust_list_t list,
             return ret;
         }
 
-        hash = _gnutls_bhash(dn.data, dn.size, INIT_HASH);
+        hash = hash_pjw_bare(dn.data, dn.size);
         hash %= list->size;
 
         _gnutls_free_datum(&dn);
@@ -570,9 +631,10 @@ gnutls_x509_trust_list_verify_crt(gnutls_x509_trust_list_t list,
  * @verify: will hold the certificate verification output.
  * @func: If non-null will be called on each chain element verification with the output.
  *
- * This function will try to find a matching named certificate. If a
- * match is found the certificate is considered valid. In addition to that
- * this function will also check CRLs.
+ * This function will try to find a certificate that is associated with the provided 
+ * name --see gnutls_x509_trust_list_add_named_crt(). If a match is found the certificate is considered valid. In addition to that
+ * this function will also check CRLs. The @verify parameter will hold an OR'ed sequence of
+ * %gnutls_certificate_status_t flags.
  *
  * Returns: On success, %GNUTLS_E_SUCCESS (0) is returned, otherwise a
  *   negative error value.
@@ -599,7 +661,7 @@ gnutls_x509_trust_list_verify_named_crt(gnutls_x509_trust_list_t list,
         return ret;
     }
 
-    hash = _gnutls_bhash(dn.data, dn.size, INIT_HASH);
+    hash = hash_pjw_bare(dn.data, dn.size);
     hash %= list->size;
 
     _gnutls_free_datum(&dn);
@@ -653,7 +715,7 @@ _gnutls_trustlist_inlist (gnutls_x509_trust_list_t list,
       return ret;
     }
 
-  hash = _gnutls_bhash(dn.data, dn.size, INIT_HASH);
+  hash = hash_pjw_bare(dn.data, dn.size);
   hash %= list->size;
 
   _gnutls_free_datum (&dn);
